# external package imports.
from enum import Enum

# our package imports.
from .bstutils import export

@export
class SoundTouchNotifyCategorys(Enum):
    """
    This class contains all event type categories that are generated by the SoundTouch 
    device event notification system when an event is processed.
    
    These constants can be used when adding and removing event listeners in the
    bosesoundtouchapi.ws.soundtouchwebsocket.SoundTouchWebSocket class.
    """
    ALL = '*'
    
    connectionStateUpdated = 'connectionStateUpdated'
    """
    Occurs when a network connection state has changed.  This normally happens when the device
    senses a wifi signal change (e.g. signal strength goes from poor to excellent, etc).
    """
    
    criticalErrorUpdate = 'criticalErrorUpdate'
    
    errorNotification = 'errorNotification'
    
    errorUpdate = 'errorUpdate'
    
    groupUpdated = 'groupUpdated'
    """ 
    Occurs when a group has been modified (created, member added, member removed, etc) on the device.
    """
    
    infoUpdated = 'infoUpdated'
    
    languageUpdated = 'languageUpdated'
    
    LowPowerStandbyUpdate = 'LowPowerStandbyUpdate'
    
    nameUpdated = 'nameUpdated'
    """ 
    Occurs when the device name has been updated.
    """
    
    nowPlayingUpdated = 'nowPlayingUpdated'
    """
    Occurs when the currently playing media source has changed.
    Some examples of this event are:  
    - when listening to a radio station / airplay / bluetooth, and the next song comes on.
    - when the device is powered down into STANDBY state.
    """
    
    nowSelectionUpdated = 'nowSelectionUpdated'
    """
    Occurs when the source selection has changed (e.g. switch from AirPlay to BlueTooth), as 
    well as when the device is powered on / off.
    """
    
    presetsUpdated = 'presetsUpdated'
    """ 
    Occurs when a preset has been updated, added, or removed from the device.
    """
    
    recentsUpdated = 'recentsUpdated'
    """ 
    Occurs when a recently played item has been updated, added, or removed from the device.
    """
    
    soundTouchConfigurationUpdated = 'soundTouchConfigurationUpdated'
    
    SoundTouchSdkInfo = 'SoundTouchSdkInfo'
    """ 
    Server version and build information. 
    It occurs when the initial connection to the SoundTouch device notification server is made.
    """
    
    sourcesUpdated = 'sourcesUpdated'
    
    swUpdateStatusUpdated = 'swUpdateStatusUpdated'
    
    userActivityUpdate = 'userActivityUpdate'
    """ 
    Occurs when a user has manually sent the device a request; some examples of this are:  
    - a button is pressed on the devices' physical remote control.  
    - the volume down / up button was pressed on the physical device.  
    """
    
    volumeUpdated = 'volumeUpdated'
    """ 
    Occurs when the device volume level has been changed.
    """
    
    WebSocketClose = 'WebSocketClose'
    """
    Occurs when a websocket close is encountered (e.g. ConnectionResetError, etc).  This can occur
    when the SoundTouch device is powered off after a connection was been made to it via a websocket.
    """
    
    WebSocketError = 'WebSocketError'
    """
    Occurs when a websocket error is encountered (e.g. ConnectionResetError, etc).  This can occur
    when the SoundTouch device is powered off after a connection was been made to it via a websocket.
    """
    
    zoneUpdated = 'zoneUpdated'
    """ 
    Occurs when a zone has been modified (created, member added, member removed, etc) on the device.
    """

    @staticmethod    
    def toString(category) -> str:
        """ Returns the enum.value (instead of classname.value) as a string. """
        if isinstance(category, (SoundTouchNotifyCategorys)):
            return category.value
        return str(category)
